@@ -25,10 +25,6 @@ func runHelpCommand(clArgs []string) {
 		runEnumCommand(help)
 	case "intel":
 		runIntelCommand(help)
-	case "track":
-		runTrackCommand(help)
-	case "viz":
-		runVizCommand(help)
 	default:
 		commandUsage(mainUsageMsg, helpCommand, helpBuf)
 		return
